@@ -951,7 +951,7 @@ function hideStatusMessage() {
  * @return  Object  Returns the div object of the textbox
  * @author  Lars Michelsen <lm@larsmichelsen.com>
  */
-function renderNagVisTextbox(id, bgColor, borderColor, x, y, z, w, h, text, customStyle) {
+function renderNagVisTextbox(id, bgColor, borderColor, x, y, z, w, h, text, customStyle, scale) {
     var oLabelDiv = document.createElement('div');
     oLabelDiv.setAttribute('id', id);
     oLabelDiv.className = 'box';
@@ -969,6 +969,9 @@ function renderNagVisTextbox(id, bgColor, borderColor, x, y, z, w, h, text, cust
 
     oLabelDiv.style.zIndex = parseInt(z) + 1;
 
+    if (scale)
+        oLabelDiv.style.transform = `scale(${scale})`;
+
     /**
      * IE workaround: The transparent for the color is not enough. The border
      * has really to be hidden.
@@ -1151,8 +1154,7 @@ function pxToInt(v) {
 // san francisco and zooming to new your will lead to a negative 5 digit
 // negative coord).
 function isRelativeCoord(v) {
-    return isset(v) && ((!isInt(v) && !isFloat(v))
-                        || (v.length === 6 && v.charAt(0) != "-" && v.indexOf(".") == -1));
+    return typeof(v) === 'string' && v.includes('%')
 }
 
 // Helper function to determine the number of entries in an object
@@ -1237,7 +1239,7 @@ function getEffectiveStyle(e, attr) {
         // Object local
         return e.style[attr];
     } else if(document.defaultView && document.defaultView.getComputedStyle) {
-        // DOM 
+        // DOM
         return document.defaultView.getComputedStyle(e, null).getPropertyValue(attr);
     } else if(e.currentStyle){
         // IE
@@ -1263,7 +1265,7 @@ function getZoomFactor() {
     if (zoom === null || zoom == 'fill')
         g_zoom_factor = 100;
     else
-        g_zoom_factor = parseInt(zoom); 
+        g_zoom_factor = parseInt(zoom);
 
     return g_zoom_factor;
 }
@@ -1397,14 +1399,8 @@ function _(s, replace) {
 }
 
 function has_class(o, cn) {
-    if (typeof o.className === 'undefined')
-        return false;
-    var parts = o.className.split(' ');
-    for (var x = 0; x < parts.length; x++) {
-        if (parts[x] == cn)
-            return true;
-    }
-    return false;
+    if (!o.classList) return false;
+    return o.classList.contains(cn);
 }
 
 function remove_class(o, cn) {
