@@ -301,7 +301,7 @@ class GlobalMapCfg {
         // here.
         if(version_compare(PHP_VERSION, '5.1.2', '==')) {
             $file = file($this->configFile);
-        } else { 
+        } else {
             $file = file($this->configFile, FILE_SKIP_EMPTY_LINES | FILE_IGNORE_NEW_LINES);
         }
 
@@ -624,7 +624,7 @@ class GlobalMapCfg {
             } else {
                 $val = $_REQUEST[$key];
             }
-                
+
             if(!$only_customized || ($val != $this->getValue(0, $key))) {
                 return $val;
             }
@@ -634,7 +634,7 @@ class GlobalMapCfg {
             $userParams = $USERCFG->getValue('params-' . $this->name);
             if(isset($userParams[$key])) {
                 return $userParams[$key];
-                
+
             } elseif(!$only_user_supplied) {
                 // Otherwise use the map global value (if allowed)
                 return $this->getValue(0, $key);
@@ -966,9 +966,10 @@ class GlobalMapCfg {
         foreach(array_keys($this->mapConfig) AS $id) {
             $todo = false;
 
-            // Replace default integer object IDs
-            if($id[0] == '_')
+            // Replace default integer object IDs (are added with "_[index]" during config parsing)
+            if($id !== 0 && $id[0] == '_') {
                 $todo = true;
+            }
 
             // Remove duplicates by generating new IDs for the later objects
             if(isset($alreadySeen[$id])) {
@@ -1545,6 +1546,11 @@ class GlobalMapCfg {
             if(is_array($val))
                 $val = implode(',', $val);
 
+            $val = str_replace( "\n", '<br/>', $val );
+            $val = str_replace( "\r", '', $val );
+            $val = str_replace( "\t", ' ', $val );
+            $val = preg_replace( '/[\x00-\x1f]/', '', $val );
+
             $newLine = $key.'='.$val."\n";
 
             if($lineNum !== null && $newLine !== '') {
