@@ -110,11 +110,13 @@ function listZoomFactors() {
 
 function getObjectNames($type, $MAPCFG, $objId, $attrs) {
     global $_BACKEND;
+    $backendIds = false;
     if (isset($attrs['backend_id']) && $attrs['backend_id'] != '') {
         $backendIds = $attrs['backend_id'];
     } elseif ($objId !== null) {
         $backendIds = $MAPCFG->getValue($objId, 'backend_id');
-    } else {
+    }
+    if (!$backendIds) {
         $backendIds = $MAPCFG->getValue(0, 'backend_id');
     }
 
@@ -541,6 +543,20 @@ $mapConfigVars = Array(
         'depends_on'    => 'view_type',
         'depends_value' => 'line'
     ),
+    'line_label_in' => Array(
+        'must'          => 0,
+        'default'       => 'in',
+        'match'         => MATCH_STRING,
+        'depends_on'    => 'view_type',
+        'depends_value' => 'line',
+    ),
+    'line_label_out' => Array(
+        'must'          => 0,
+        'default'       => 'out',
+        'match'         => MATCH_STRING,
+        'depends_on'    => 'view_type',
+        'depends_value' => 'line',
+    ),
     'line_label_y_offset' => Array(
         'must'          => 0,
         'default'       => 2,
@@ -650,6 +666,11 @@ $mapConfigVars = Array(
         'default'    => cfg('defaults', 'showinmultisite'),
         'match'      => MATCH_BOOLEAN,
         'field_type' => 'boolean'),
+    'ignore_linked_maps_summary_state' => Array(
+        'must'       => 0,
+        'default'    => '0',
+        'match'      => MATCH_BOOLEAN,
+        'field_type' => 'boolean'),
     'stylesheet' => Array(
         'must' => 0,
         'default' => cfg('defaults', 'stylesheet'),
@@ -832,6 +853,7 @@ $mapConfigVars = Array(
     'text' => Array(
         'must' => 1,
         'match' => MATCH_ALL,
+        'field_type'    => 'textarea',
     ),
     'border_color' => Array(
         'must'       => 0,
@@ -839,6 +861,12 @@ $mapConfigVars = Array(
         'field_type' => 'color',
         'match'      => MATCH_COLOR,
     ),
+    'scale_to_max_zoom' => Array(
+        'must'       => 0,
+        'default'    => 0,
+        'match'      => MATCH_BOOLEAN,
+        'field_type' => 'boolean',
+    ),
     'style' => Array(
         'must' => 0,
         'default' => '',
@@ -888,9 +916,9 @@ $mapConfigVars = Array(
         'match' => MATCH_STRING_NO_SPACE,
         'list'  => 'listTemplateNames',
     ),
-    
+
     // STATELESS LINE SPECIFIC OPTIONS
-    
+
     'view_type_line' => Array(
         'must'          => 1,
         'default'       => 'line',
@@ -930,7 +958,7 @@ $mapConfigVars = Array(
         'default'    => '',
         'field_type' => 'dropdown',
         'match'      => MATCH_DYN_GROUP_TYPES,
-        'list'       => 'listDynGroupTypes', 
+        'list'       => 'listDynGroupTypes',
     ),
     'object_filter' => Array(
         'must'       => 0,
@@ -974,6 +1002,7 @@ $mapConfigVarMap['global'] = Array(
         'in_maintenance' => null,
         'show_in_lists' => null,
         'show_in_multisite' => null,
+        'ignore_linked_maps_summary_state' => null,
     ),
     'appearance' => array(
         'map_image' => null,
@@ -1186,6 +1215,8 @@ $mapConfigVarMap['service'] = Array(
         'line_type' => null,
         'line_cut' => null,
         'line_label_show' => null,
+        'line_label_in' => null,
+        'line_label_out' => null,
         'line_label_pos_in' => null,
         'line_label_pos_out' => null,
         'line_label_y_offset' => null,
@@ -1402,6 +1433,9 @@ $mapConfigVarMap['textbox'] = Array(
         'type' => null,
         'use' => null,
     ),
+    'worldmap' => array(
+        'scale_to_max_zoom' => null,
+    )
 );
 
 $mapConfigVarMap['shape'] = Array(
@@ -1578,7 +1612,7 @@ $mapConfigVarMap['aggr'] = Array(
         'label_border'          => null,
         'label_style'           => null,
         'label_maxlen'          => null,
-    
+
     ),
     'hidden' => array(
         'type'                  => null,
